@@ -134,7 +134,7 @@ pref("gfx.color_management.display_profile", "");
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 138 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 138 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -147,7 +147,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 154 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 154 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -343,6 +343,8 @@ pref("capability.policy.mailnews.*.data.get", "noAccess");
 pref("capability.policy.mailnews.*.getAttribute", "noAccess");
 pref("capability.policy.mailnews.HTMLDivElement.getAttribute", "sameOrigin");
 pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNode", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNodeNS", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItem", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");
 pref("capability.policy.mailnews.*.host.get", "noAccess");
@@ -356,11 +358,13 @@ pref("capability.policy.mailnews.*.protocol.get", "noAccess");
 pref("capability.policy.mailnews.*.src.get", "noAccess");
 pref("capability.policy.mailnews.*.substringData.get", "noAccess");
 pref("capability.policy.mailnews.*.text.get", "noAccess");
+pref("capability.policy.mailnews.*.textContent", "noAccess");
 pref("capability.policy.mailnews.*.title.get", "noAccess");
 pref("capability.policy.mailnews.DOMException.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLAnchorElement.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.domain", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.URL", "noAccess");
+pref("capability.policy.mailnews.*.documentURI", "noAccess");
 pref("capability.policy.mailnews.Location.toString", "noAccess");
 pref("capability.policy.mailnews.Range.toString", "noAccess");
 pref("capability.policy.mailnews.Window.blur", "noAccess");
@@ -523,7 +527,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 532 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 536 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -639,6 +643,7 @@ pref("network.IDN_show_punycode", false);
 
 // ccTLDs
 pref("network.IDN.whitelist.ac", true);
+pref("network.IDN.whitelist.ar", true);
 pref("network.IDN.whitelist.at", true);
 pref("network.IDN.whitelist.br", true);
 pref("network.IDN.whitelist.ch", true);
@@ -752,7 +757,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 766 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 771 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -776,9 +781,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 791 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 796 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 798 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 803 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1112,15 +1117,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1515 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 1520 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1932 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 1937 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2129 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2134 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2220 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2225 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2223 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2228 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1380,20 +1385,20 @@ pref("print.postscript.paper_size",    "letter");
 pref("print.postscript.orientation",   "portrait");
 pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2485 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2490 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2553 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2558 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2579 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2584 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2599 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2604 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2601 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2606 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2607 "/export/home/mozilla/uild/firefox-3.0.3/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2612 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
